#
# Currently debuginfo breaks the build.
#
# I get one of the following two failures following recommended debuginfo
# methods for golang:
#
#   *** ERROR: No build ID note found in /builddir/build/BUILDROOT/reg-0.4.1-1.x86_64/usr/bin/reg-server
#
# or:
#
#   /var/tmp/rpm-tmp.U9Lwrk: line 36: syntax error near unexpected token `)'
#
%global debug_package %{nil}

# https://bugzilla.redhat.com/show_bug.cgi?id=995136#c12
%global _dwz_low_mem_die_limit 0

# modifying the Go binaries breaks the DWARF debugging
%global __os_install_post %{_rpmconfigdir}/brp-compress

%global provider_prefix github.com/jessfraz/reg
%global import_path     %{provider_prefix}
%global commit          8d8ca405f7a8c8c4f72686ed239c767aba663f9b
%global shortcommit     %(c=%{commit}; echo ${c:0:7})

Name:       reg
Version:    0.4.1
Release:    5%{?dist}
Summary:    Docker registry v2 command line client


License:    MIT
URL:        https://%{import_path}/%{name}

# Upstream doesn't have any official releases or any git tags to reference,
# however in the source code it claims to be version "0.2.0" as is found by
# executing the `reg` command and getting usage output.
#
Source0:    https://%{import_path}/%{name}/archive/%{commit}/%{name}-%{version}.tar.gz

# Upstream'd patch, but not in a release yet. This allows the reg-server command
# to be executed once and create the static html but not start an embedded http
# service.
Patch0:     reg-server-0.4.1-run-once.patch

# Upstream advertises this as something that's meant to be run in a container
# and doesn't provide a systemd unit or sysV init script or sysconfig files
# so I'm providing them here.
Source1:    reg-server.service
Source2:    sysconfig.reg-server

BuildRequires: golang
BuildRequires: systemd

%if 0%{?epel}
# The version of golang is too old to understand the vendor manifest and can't
# find the appropriate path for the vendored version of this.
BuildRequires: golang-github-gorilla-context-devel

# For whatever reason golang-github-gorilla-context-devel isn't available in
# EPEL for any of the other arches.
#   BZ filed: https://bugzilla.redhat.com/show_bug.cgi?id=1466521
ExclusiveArch: x86_64
%endif # 0%{?epel}

# The following section is automatically populated by running the below python
# one-liner at the base dir of a git checkout of the source code.
#
#   $ git clone https://github.com/jessfraz/reg.git
#   $ cd reg
#   $ python -c 'import json; print "\n".join(["Provides: bundled(golang({})) = {}".format(dep[u"importpath"], dep[u"revision"]) for dep in json.load(open("vendor/manifest", "r"))[u"dependencies"]])'
#
# Bundled Provides are defined as per Fedora Guidelines:
#   https://fedoraproject.org/wiki/Packaging:Guidelines#Bundling_and_Duplication_of_system_libraries
#
Provides: bundled(golang(github.com/BurntSushi/toml)) = 99064174e013895bbd9b025c31100bd1d9b590ca
Provides: bundled(golang(github.com/GeertJohan/go.incremental)) = 1172aab965109e2a70720a0f144b2a5dfeb92fa5
Provides: bundled(golang(github.com/GeertJohan/go.rice)) = c02ca9a983da5807ddf7d796784928f5be4afd09
Provides: bundled(golang(github.com/Microsoft/go-winio)) = fff283ad5116362ca252298cfc9b95828956d85d
Provides: bundled(golang(github.com/Nvveen/Gotty)) = cd527374f1e5bff4938207604a14f2e38a9cf512
Provides: bundled(golang(github.com/Sirupsen/logrus)) = 0208149b40d863d2c1a2f8fe5753096a9cf2cc8b
Provides: bundled(golang(github.com/akavel/rsrc/binutil)) = ba14da1f827188454a4591717fff29999010887f
Provides: bundled(golang(github.com/akavel/rsrc/coff)) = ba14da1f827188454a4591717fff29999010887f
Provides: bundled(golang(github.com/daaku/go.zipexe)) = a5fe2436ffcb3236e175e5149162b41cd28bd27d
Provides: bundled(golang(github.com/davecgh/go-spew/spew)) = 346938d642f2ec3594ed81d874461961cd0faa76
Provides: bundled(golang(github.com/dgrijalva/jwt-go)) = 2268707a8f0843315e2004ee4f1d021dc08baedf
Provides: bundled(golang(github.com/docker/distribution)) = 08b06dc023674763e7b36d404cf0c7664cee1f5e
Provides: bundled(golang(github.com/docker/docker/api)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/cli/config)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/client)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/daemon/cluster)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/daemon/graphdriver)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/daemon/initlayer)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/daemon/logger)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/distribution)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/dockerversion)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/image)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/layer)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/libcontainerd)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/oci)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/opts)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/pkg/archive)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/authorization)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/chrootarchive)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/devicemapper)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/directory)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/discovery)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/filenotify)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/fileutils)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/fsutils)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/homedir)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/pkg/httputils)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/pkg/idtools)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/pkg/ioutils)) = f6b7dc983782e5800bdfd901f963494df9fbb0b7
Provides: bundled(golang(github.com/docker/docker/pkg/jsonlog)) = f6b7dc983782e5800bdfd901f963494df9fbb0b7
Provides: bundled(golang(github.com/docker/docker/pkg/jsonmessage)) = f6b7dc983782e5800bdfd901f963494df9fbb0b7
Provides: bundled(golang(github.com/docker/docker/pkg/locker)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/longpath)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/pkg/loopback)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/mount)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/namesgenerator)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/parsers)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/plugingetter)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/plugins)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/pools)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/progress)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/pkg/promise)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/pubsub)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/random)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/pkg/reexec)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/signal)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/stdcopy)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/streamformatter)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/pkg/stringid)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/pkg/symlink)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/sysinfo)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/system)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/pkg/tailfile)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/tarsum)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/pkg/templates)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/term)) = f6b7dc983782e5800bdfd901f963494df9fbb0b7
Provides: bundled(golang(github.com/docker/docker/pkg/tlsconfig)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/urlutil)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/pkg/useragent)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/plugin)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/reference)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/registry)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/runconfig)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/cloud.google.com/go/compute/metadata)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/cloud.google.com/go/internal)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/cloud.google.com/go/logging)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/Azure/go-ansiterm)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/BurntSushi/toml)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/Graylog2/go-gelf/gelf)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/Microsoft/go-winio)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/Microsoft/hcsshim)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/Nvveen/Gotty)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/RackSec/srslog)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/Sirupsen/logrus)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/armon/go-metrics)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/armon/go-radix)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/aws/aws-sdk-go/aws)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/aws/aws-sdk-go/private/endpoints)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/aws/aws-sdk-go/private/protocol)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/aws/aws-sdk-go/service/cloudwatchlogs)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/aws/aws-sdk-go/service/sts)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/beorn7/perks/quantile)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/boltdb/bolt)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/bsphere/le_go)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/cloudflare/cfssl/api)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/cloudflare/cfssl/auth)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/cloudflare/cfssl/certdb)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/cloudflare/cfssl/config)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/cloudflare/cfssl/crypto/pkcs7)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/cloudflare/cfssl/csr)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/cloudflare/cfssl/errors)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/cloudflare/cfssl/helpers)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/cloudflare/cfssl/info)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/cloudflare/cfssl/initca)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/cloudflare/cfssl/log)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/cloudflare/cfssl/ocsp/config)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/cloudflare/cfssl/signer)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/coreos/etcd/client)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/coreos/etcd/pkg/crc)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/coreos/etcd/pkg/fileutil)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/coreos/etcd/pkg/idutil)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/coreos/etcd/pkg/ioutil)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/coreos/etcd/pkg/pathutil)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/coreos/etcd/pkg/pbutil)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/coreos/etcd/pkg/types)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/coreos/etcd/raft)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/coreos/etcd/snap)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/coreos/etcd/wal)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/coreos/go-systemd/journal)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/coreos/pkg/capnslog)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/deckarep/golang-set)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/containerd/api/grpc/types)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/distribution)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/docker-credential-helpers/client)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/docker-credential-helpers/credentials)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/go-connections/nat)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/go-connections/sockets)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/go-connections/tlsconfig)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/go-events)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/go-units)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/libkv)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/libnetwork)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/libtrust)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/swarmkit/agent)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/swarmkit/api)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/swarmkit/ca)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/swarmkit/connectionbroker)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/swarmkit/identity)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/swarmkit/ioutils)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/swarmkit/log)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/swarmkit/manager)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/swarmkit/node)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/swarmkit/protobuf/plugin)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/swarmkit/protobuf/ptypes)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/swarmkit/remotes)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/swarmkit/template)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/swarmkit/watch)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/docker/swarmkit/xnet)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/fluent/fluent-logger-golang/fluent)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/fsnotify/fsnotify)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/go-ini/ini)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/godbus/dbus)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/gogo/protobuf/gogoproto)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/gogo/protobuf/proto)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/gogo/protobuf/protoc-gen-gogo/descriptor)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/gogo/protobuf/sortkeys)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/gogo/protobuf/types)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/golang/mock/gomock)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/golang/protobuf/proto)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/golang/protobuf/protoc-gen-go/descriptor)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/golang/protobuf/ptypes)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/google/certificate-transparency/go)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/googleapis/gax-go)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/gorilla/context)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/gorilla/mux)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/grpc-ecosystem/go-grpc-prometheus)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/hashicorp/consul/api)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/hashicorp/go-immutable-radix)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/hashicorp/go-memdb)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/hashicorp/go-msgpack/codec)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/hashicorp/go-multierror)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/hashicorp/golang-lru/simplelru)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/hashicorp/memberlist)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/hashicorp/serf/coordinate)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/hashicorp/serf/serf)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/jmespath/go-jmespath)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/mattn/go-shellwords)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/matttproud/golang_protobuf_extensions/pbutil)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/miekg/dns)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/mistifyio/go-zfs)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/opencontainers/go-digest)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/opencontainers/runc/libcontainer/cgroups)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/opencontainers/runc/libcontainer/configs)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/opencontainers/runc/libcontainer/devices)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/opencontainers/runc/libcontainer/label)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/opencontainers/runc/libcontainer/selinux)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/opencontainers/runc/libcontainer/system)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/opencontainers/runc/libcontainer/user)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/opencontainers/runtime-spec/specs-go)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/pborman/uuid)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/philhofer/fwd)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/pivotal-golang/clock)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/pkg/errors)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/prometheus/client_golang/prometheus)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/prometheus/client_model/go)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/prometheus/common/expfmt)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/prometheus/common/internal/bitbucket.org/ww/goautoneg)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/prometheus/common/model)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/prometheus/procfs)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/samuel/go-zookeeper/zk)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/spf13/pflag)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/tinylib/msgp/msgp)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/tonistiigi/fifo)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/ugorji/go/codec)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/vbatts/tar-split/archive/tar)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/vbatts/tar-split/tar/asm)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/vbatts/tar-split/tar/storage)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/vishvananda/netlink)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/github.com/vishvananda/netns)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/crypto/nacl/secretbox)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/crypto/pkcs12)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/crypto/poly1305)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/crypto/salsa20/salsa)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/net/context)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/net/http2)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/net/idna)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/net/internal/timeseries)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/net/lex/httplex)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/net/proxy)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/net/trace)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/net/websocket)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/oauth2)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/sys/unix)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/sys/windows)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/text/internal/gen)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/text/internal/triegen)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/text/internal/ucd)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/text/secure/bidirule)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/text/transform)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/text/unicode/bidi)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/text/unicode/cldr)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/text/unicode/norm)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/text/unicode/rangetable)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/golang.org/x/time/rate)) = 338565805c31783c63f9bb35d5b24f4c0c5656d3
Provides: bundled(golang(github.com/docker/docker/vendor/google.golang.org/api/googleapi/transport)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/google.golang.org/api/internal)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/google.golang.org/api/iterator)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/google.golang.org/api/option)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/google.golang.org/api/support/bundler)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/google.golang.org/api/transport)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/google.golang.org/genproto/googleapis/api/annotations)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/google.golang.org/genproto/googleapis/api/label)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/google.golang.org/genproto/googleapis/api/monitoredres)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/google.golang.org/genproto/googleapis/logging/type)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/google.golang.org/genproto/googleapis/logging/v2)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/google.golang.org/genproto/googleapis/rpc/status)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/vendor/google.golang.org/grpc)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/docker/volume)) = d7e7aa67ea5278467644074f19d428851ebc34f4
Provides: bundled(golang(github.com/docker/go-connections/nat)) = a2afab9802043837035592f1c24827fb70766de9
Provides: bundled(golang(github.com/docker/go-connections/sockets)) = e15c02316c12de00874640cd76311849de2aeed5
Provides: bundled(golang(github.com/docker/go-connections/tlsconfig)) = e15c02316c12de00874640cd76311849de2aeed5
Provides: bundled(golang(github.com/docker/go-units)) = 0dadbb0345b35ec7ef35e228dabb8de89a65bf52
Provides: bundled(golang(github.com/docker/libtrust)) = aabc10ec26b754e797f9028f4589c5b7bd90dc20
Provides: bundled(golang(github.com/dustin/go-humanize)) = 259d2a102b871d17f30e3cd9881a642961a1e486
Provides: bundled(golang(github.com/facebookgo/clock)) = 600d898af40aa09a7a93ecb9265d87b0504b6f03
Provides: bundled(golang(github.com/facebookgo/grace/gracehttp)) = 4afe952a37a495ae4ac0c1d4ce5f66e91058d149
Provides: bundled(golang(github.com/facebookgo/grace/gracenet)) = 4afe952a37a495ae4ac0c1d4ce5f66e91058d149
Provides: bundled(golang(github.com/facebookgo/httpdown)) = a3b1354551a26449fbe05f5d855937f6e7acbd71
Provides: bundled(golang(github.com/facebookgo/stats)) = 1b76add642e42c6ffba7211ad7b3939ce654526e
Provides: bundled(golang(github.com/golang/protobuf/proto)) = 2bba0603135d7d7f5cb73b2125beeda19c09f4ef
Provides: bundled(golang(github.com/golang/protobuf/ptypes/any)) = 2bba0603135d7d7f5cb73b2125beeda19c09f4ef
Provides: bundled(golang(github.com/gorilla/context)) = 08b5f424b9271eedf6f9f0ce86cb9396ed337a42
Provides: bundled(golang(github.com/gorilla/mux)) = 599cba5e7b6137d46ddf58fb1765f5d928e69604
Provides: bundled(golang(github.com/gorilla/websocket)) = a91eba7f97777409bc2c443f5534d41dd20c5720
Provides: bundled(golang(github.com/jessevdk/go-flags)) = 460c7bb0abd6e927f2767cadc91aa6ef776a98b4
Provides: bundled(golang(github.com/kardianos/osext)) = 9d302b58e975387d0b4d9be876622c86cefe64be
Provides: bundled(golang(github.com/labstack/echo)) = 8173bb8f2d7ba81d65a4a33d67fd689ccc39e419
Provides: bundled(golang(github.com/labstack/gommon/bytes)) = 9298d710c664bcd21c454120f63a00fb7d484458
Provides: bundled(golang(github.com/labstack/gommon/color)) = 9298d710c664bcd21c454120f63a00fb7d484458
Provides: bundled(golang(github.com/labstack/gommon/log)) = 9298d710c664bcd21c454120f63a00fb7d484458
Provides: bundled(golang(github.com/labstack/gommon/random)) = 9298d710c664bcd21c454120f63a00fb7d484458
Provides: bundled(golang(github.com/mattn/go-colorable)) = ded68f7a9561c023e790de24279db7ebf473ea80
Provides: bundled(golang(github.com/mattn/go-isatty)) = fc9e8d8ef48496124e79ae0df75490096eccf6fe
Provides: bundled(golang(github.com/mitchellh/go-wordwrap)) = ad45545899c7b13c020ea92b2072220eefad42b8
Provides: bundled(golang(github.com/opencontainers/go-digest)) = aa2ec055abd10d26d539eb630a92241b781ce4bc
Provides: bundled(golang(github.com/opencontainers/runc/libcontainer/user)) = 291bf601105c97dc1aa631fdfb7fca63c947319b
Provides: bundled(golang(github.com/peterhellberg/link)) = 3eea38ca14b7b3252feea5daf92be3864209eb1d
Provides: bundled(golang(github.com/pkg/errors)) = ff09b135c25aae272398c51a07235b90a75aa4f0
Provides: bundled(golang(github.com/tylerb/graceful)) = d72b0151351a13d0421b763b88f791469c4f5dc7
Provides: bundled(golang(github.com/urfave/cli)) = 9e5b04886c4bfee2ceba1465b8121057355c4e53
Provides: bundled(golang(github.com/urfave/negroni)) = c0db5feaa33826cd5117930c8f4ee5c0f565eec6
Provides: bundled(golang(github.com/valyala/bytebufferpool)) = e746df99fe4a3986f4d4f79e13c1e0117ce9c2f7
Provides: bundled(golang(github.com/valyala/fasttemplate)) = dcecefd839c4193db0d35b88ec65b4c12d360ab0
Provides: bundled(golang(golang.org/x/crypto/acme)) = 3543873453996aaab2fc6b3928a35fc5ca2b5afb
Provides: bundled(golang(golang.org/x/net/context)) = ffcf1bedda3b04ebb15a168a59800a73d6dc0f4d
Provides: bundled(golang(golang.org/x/net/proxy)) = ffcf1bedda3b04ebb15a168a59800a73d6dc0f4d
Provides: bundled(golang(golang.org/x/net/websocket)) = d212a1ef2de2f5d441c327b8f26cf3ea3ea9f265
Provides: bundled(golang(golang.org/x/sys/unix)) = b90f89a1e7a9c1f6b918820b3daa7f08488c8594
Provides: bundled(golang(golang.org/x/sys/windows)) = 493114f68206f85e7e333beccfabc11e98cba8dd
Provides: bundled(golang(google.golang.org/appengine)) = 56d253d1dd14aa01937e12c73a0971bcfd797ff2
Provides: bundled(golang(gopkg.in/airbrake/gobrake.v2)) = 668876711219e8b0206e2994bf0a59d889c775aa
Provides: bundled(golang(gopkg.in/gemnasium/logrus-airbrake-hook.v2)) = bfee1239d796830ca346767650cce5ba90d58c57
Provides: bundled(golang(gopkg.in/mgo.v2)) = 3f83fa5005286a7fe593b055f0d7771a7dce4655
Provides: bundled(golang(gopkg.in/tomb.v2)) = d5d1b5820637886def9eef33e03a27a9f166942c
Provides: bundled(golang(gopkg.in/tylerb/graceful.v1)) = 4654dfbb6ad53cb5e27f37d99b02e16c1872fbbb
Provides: bundled(golang(gopkg.in/urfave/cli.v1)) = 0bdeddeeb0f650497d603c4ad7b20cfe685682f6
Provides: bundled(golang(gopkg.in/yaml.v2)) = a3f3340b5840cee44f372bddb5880fcbc419b46a

%description
Docker registry v2 client.

%package server
Summary: A static UI for a docker registry
Requires: systemd
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd

%description server
A static UI for a docker registry. Comes with vulnerability scanning if you
have a CoreOS Clair server set up.


%prep
%setup -q -n %{name}-%{commit}

%patch0 -p1

# Have to move things around because of how golang likes to search $GOPATH
cd ../
mv $OLDPWD hack
mkdir $OLDPWD
cd $OLDPWD
mkdir -p $(pwd)/go/src/%{import_path}
mv ../hack/* $(pwd)/go/src/%{import_path}/

# Have to mess with the pathing even more to make the older version of golang
# in el7 happy.
%if 0%{?epel}
for d in $(ls $(pwd)/go/src/%{import_path}/vendor/)
do
    if [[ -d "$(pwd)/go/src/%{import_path}/vendor/${d}" ]]; then
        printf "D VALUE: %s\n" "${d}"
        mkdir -p $(pwd)/go/src/${d}
        cp -r $(pwd)/go/src/%{import_path}/vendor/${d}/* $(pwd)/go/src/${d}/
    fi
done
%endif # 0%{?epel}

%build
export GOPATH="$(pwd)/go:%{buildroot}%{gopath}:%{gopath}"

cd $(pwd)/go/src/%{import_path}/

# Leave this here for when we can sort out the debuginfo fix
#   https://bugzilla.redhat.com/show_bug.cgi?id=1432214
#go build \
#    -ldflags '-B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d \' \\n\')' \
#    -o reg .
#
#go build \
#    -ldflags '-B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d \' \\n\')' \
#    -o reg-server ./server

go build -o reg .

go build -o reg-server ./server

%install

# Install the binaries
cd ./go/src/%{import_path}/
mkdir -p %{buildroot}%{_bindir}
install -p -m 0755 %{name} %{buildroot}%{_bindir}/%{name}
install -p -m 0755 %{name}-server %{buildroot}%{_bindir}/%{name}-server

# Install templates and static content
mkdir -p %{buildroot}%{_sharedstatedir}/%{name}-server
install -d server/templates/ %{buildroot}/%{_sharedstatedir}/%{name}-server/templates/
install -d server/static/ %{buildroot}%{_sharedstatedir}/%{name}-server/static/
cp -p -r server/templates/* %{buildroot}%{_sharedstatedir}/%{name}-server/templates/
cp -p -r server/static/* %{buildroot}%{_sharedstatedir}/%{name}-server/static/

# Install the systemd unit
mkdir -p %{buildroot}%{_unitdir}
install -p -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}-server.service

# Install the sysconfig file
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -p -m 0640 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}-server


mkdir -p %{buildroot}/%{name}-%{version}

# Setup doc files for doc macro
for i in README.md Dockerfile Makefile
do
    cp -p ${i} %{_builddir}/%{name}-%{commit}/
done

# Setup doc files for reg-server doc macro
mv server/README.md server/README-server.md
for i in README-server.md home.png vuln.png
do
    cp -p server/${i} %{_builddir}/%{name}-%{commit}/
done

# Setup license file for license macro
cp -p LICENSE %{_builddir}/%{name}-%{commit}/


%post server
%systemd_post %{name}-server.service

%preun server
%systemd_preun %{name}-server.service

%postun server
%systemd_postun


%files
%doc README.md Dockerfile Makefile
%license LICENSE
%{_bindir}/%{name}

%files server
%doc README.md home.png vuln.png
%license LICENSE
%{_bindir}/%{name}-server
%{_unitdir}/%{name}-server.service
%dir %{_sharedstatedir}/%{name}-server/
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}-server
%config(noreplace) %{_sharedstatedir}/%{name}-server/static/
%config(noreplace) %{_sharedstatedir}/%{name}-server/templates/
%ghost %config(noreplace) %{_sharedstatedir}%{name}-server/index.html

%changelog
* Thu Jun 29 2017 Adam Miller <maxamillion@fedoraproject.org> - 0.4.1-5
- Actually apply the patch for single-run execution

* Thu Jun 29 2017 Adam Miller <maxamillion@fedoraproject.org> - 0.4.1-4
- Fix epel7 build

* Tue Jun 27 2017 Adam Miller <maxamillion@fedoraproject.org> - 0.4.1-3
- Add patch to allow single-run execution of reg-server for static html
  generation

* Mon Jun 19 2017 Adam Miller <maxamillion@fedoraproject.org> - 0.4.1-2
- Add ghost file entry for statically generated index.html

* Mon Jun 12 2017 Adam Miller <maxamillion@fedoraproject.org> - 0.4.1-1
- Update to latest upstream
- Switch to using upstream versioning, they are tagging versions now.

* Tue Mar 21 2017 Adam Miller <maxamillion@fedoraproject.org> - 0.2.0-2.git.0.94d0af5
- Move static/templates and systemd workingdir to /var/lib/reg-server
- Change Source0 to point to github archive url instead of local git-archive
- Fix tabs vs spaces in the spec file

* Tue Mar 14 2017 Adam Miller <maxamillion@fedoraproject.org> - 0.2.0-1.git.0.94d0af5
- First package for Fedora
